======================
Octavia Administration
======================


Getting Started
---------------

.. toctree::
   :maxdepth: 1

   ../reference/introduction.rst
   ../reference/glossary.rst
   ../contributor/guides/dev-quick-start.rst

Installation and Configuration Guides
-------------------------------------

.. toctree::
   :maxdepth: 1

   amphora-image-build
   guides/certificates.rst
   ../configuration/configref.rst
   ../configuration/policy.rst

Optional Installation and Configuration Guides
----------------------------------------------

.. toctree::
   :maxdepth: 1

   providers/index.rst
   log-offloading.rst
   api-audit.rst
   healthcheck.rst
   flavors.rst
   apache-httpd.rst

Maintanence and Operations
--------------------------

.. toctree::
   :maxdepth: 1

   guides/operator-maintenance.rst
   octavia-status
   guides/upgrade.rst

Operator Reference
------------------

.. toctree::
   :maxdepth: 1

   Octavia API Reference <https://docs.openstack.org/api-ref/load-balancer/>
   ../contributor/api/haproxy-amphora-api.rst

.. only:: html

   Indices and Search
   ------------------

   * :ref:`search`
